<?php
// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Admin settings.
 */
class BP_Profile_Visibility_BB_Admin {

	/**
	 * BP_Profile_Visibility_BB_Admin constructor.
	 */
	public function __construct() {
		add_action( 'bp_profile_visibility_settings', array( $this, 'register_settings' ) );
	}

	/**
	 * Registers settings
	 *
	 * @param OptionsBuddy_Settings_Page $page Settings page object.
	 */
	public function register_settings( $page ) {
		$basic_section = $page->add_section( 'bb_section', __( 'BuddyBoss Settings', 'bp-profile-visibility-manager' ), __( 'BuddyBoss specific settings for administrators.', 'bp-profile-visibility-manager' ) );

		$basic_section->add_fields(
			array(
				array(
					'name'    => 'enable_bb_photo_tab_visibility',
					'label'   => __( 'Enable photo tab visibility?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, users can change the visibility of the photo tab on their profile.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => 'bp_profile_bb_photo_tab_visibility',
					'label'   => __( 'Default photo tab visibility on profile?', 'bp-profile-visibility-manager' ),
					// you already know it from previous example.
					'desc'    => __( 'Set default photo tab visibility.', 'bp-profile-visibility-manager' ),
					// this is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),
				array(
					'name'    => 'enable_bb_video_tab_visibility',
					'label'   => __( 'Enable video tab visibility?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, users can change the visibility of the video tab on their profile.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => 'bp_profile_bb_video_tab_visibility',
					'label'   => __( 'Default video tab visibility on profile?', 'bp-profile-visibility-manager' ),
					// you already know it from previous example.
					'desc'    => __( 'Set default video tab visibility.', 'bp-profile-visibility-manager' ),
					// this is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),
				array(
					'name'    => 'enable_bb_document_tab_visibility',
					'label'   => __( 'Enable document tab visibility?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, users can change the visibility of the document tab on their profile.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => 'bp_profile_bb_document_tab_visibility',
					'label'   => __( 'Default document tab visibility on profile?', 'bp-profile-visibility-manager' ),
					// you already know it from previous example.
					'desc'    => __( 'Set default document tab visibility.', 'bp-profile-visibility-manager' ),
					// this is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),
				array(
					'name'    => 'enable_bb_forum_tab_visibility',
					'label'   => __( 'Enable forum tab visibility?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, users can change the visibility of the forum tab on their profile.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => 'bp_profile_bb_forum_tab_visibility',
					'label'   => __( 'Default forum tab visibility on profile?', 'bp-profile-visibility-manager' ),
					// you already know it from previous example.
					'desc'    => __( 'Set default forum tab visibility.', 'bp-profile-visibility-manager' ),
					// this is used as the description of the field.
					'type'    => 'select',
					'default' => 'public',
					'options' => bp_profile_visibility_get_visibilities(),
				),
				array(
					'name'    => 'enable_restriction_bb_wall_posting',
					'label'   => __( 'Enable wall posting restriction?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'If you enable, restriction will be applied on wall posting. Also, users can control who can post on their wall.', 'bp-profile-visibility-manager' ),
					'type'    => 'radio',
					'default' => 'no',
					'options' => array(
						'yes' => __( 'Yes', 'bp-profile-visibility-manager' ),
						'no'  => __( 'No', 'bp-profile-visibility-manager' ),
					),
				),
				array(
					'name'    => 'bp_profile_bb_wall_posting_restriction',
					'label'   => __( 'Default who can post on user wall?', 'bp-profile-visibility-manager' ),
					'desc'    => __( 'Select the default setting for who can post on user wall. It will be used if the user has not updated his/her preference.', 'bp-profile-visibility-manager' ),
					'type'    => 'select',
					'default' => 'loggedin',
					'options' => ( new BPPV_Visibility_Modifier( array( 'public', 'self' ) ) )->get(),
				),
			)
		);
	}
}

new BP_Profile_Visibility_BB_Admin();

