<?php
/**
 * Wall restriction enabler implementation for BuddyBoss
 *
 * @package    BP_Profile_Visibility_Manager
 * @subpackage Core
 * @copyright  Copyright (c) 2024, Ravi Sharma
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Wall restriction enabler class
 */
class BB_Wall_Privacy_Helper {

	/**
	 * Class instance
	 *
	 * @var self
	 */
	private static $instance = null;

	/**
	 * Constructor.
	 */
	private function __construct() {
		$this->setup();
	}

	/**
	 * Retrieves and initialize singleton instance.
	 *
	 * @return self
	 */
	public static function get_instance() {

		if ( ! self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Sets up callbacks.
	 **/
	private function setup() {
		if ( bp_profile_visibility_manager()->get_option( 'enable_restriction_bb_wall_posting' ) === 'yes' ) {
			add_filter( 'bb_user_can_create_activity', array( $this, 'can_create' ) );
		}
	}

	/**
	 * Checks if user can create activity.
	 *
	 * @param bool $can Can create or not.
	 *
	 * @return bool
	 */
	public function can_create( $can ) {
		// Returns default if user is super admin.
		if ( is_super_admin() ) {
			return $can;
		}

		// Returns if not user or its own profile.
		if ( ! bp_is_user() || bp_is_my_profile() ) {
			return $can;
		}

		$displayed_user_id = bp_displayed_user_id();
		$privacy           = bp_profile_visibility_get_settings( $displayed_user_id, 'bp_profile_bb_wall_posting_restriction' );

		if ( 'loggedin' === $privacy ) {
			$can = is_user_logged_in();
		} elseif ( 'friends' === $privacy && function_exists( 'friends_check_friendship' ) ) {
			$can = friends_check_friendship( get_current_user_id(), $displayed_user_id );
		} elseif ( 'groups' === $privacy ) {
			$can = bp_profile_visibility_has_common_group( get_current_user_id(), $displayed_user_id );
		}

		return $can;
	}
}

BB_Wall_Privacy_Helper::get_instance();
