<?php
/**
 * Visibility Modifier
 *
 * @package    BP Profile Visibility Manager
 * @subpackage Core
 * @copyright  Copyright (c) 2024, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Visibility modifier.
 */
class BPPV_Visibility_Modifier {

	/**
	 * List of visibilities to be excluded.
	 *
	 * @var array
	 */
	private $excluded = array();

	/**
	 * Constructor.
	 *
	 * @param array $excluded List of visibilities to be excluded.
	 */
	public function __construct( $excluded = array() ) {
		$this->excluded = $excluded;
	}

	/**
	 * Returns list of visibilities.
	 *
	 * @return array
	 */
	public function get() {
		$visibilities = bp_profile_visibility_get_visibilities();

		foreach ( $visibilities as $visibility => $label ) {

			if ( in_array( $visibility, (array) $this->excluded, true ) ) {
				unset( $visibilities[ $visibility ] );
			}
		}

		return array_filter( $visibilities );
	}

	/**
	 * Renders or returns visibilities dropdown.
	 *
	 * @param string $name      Name of the dropdown.
	 * @param string $id        Dropdown id.
	 * @param string $selected  Default selected.
	 * @param bool   $echo      Echo or not.
	 *
	 * @return string
	 */
	public function list( $name, $id = '', $selected = '', $echo = true ) {
		$html = sprintf( '<select name="%s" id="%s">', esc_attr( $name ), esc_attr( $id ) );

		$visibilities = $this->get();
		foreach ( $visibilities as $value => $label ) {
			$html .= sprintf( '<option value="%s" %s>%s</option>', esc_attr( $value ), selected( $value, $selected, false ), esc_html( $label ) );
		}

		$html .= "</select>";

		if ( $echo ) {
			echo $html;
		} else {
			return $html;
		}
	}
}
